@@ -70,7 +70,8 @@ echo
 echo Installing dependencies for ARM Linux targets...
 apt-get install ${APTOPTS[*]} g++-arm-linux-gnueabihf \
   libmpc-dev \
-  gmpc-dev
+  gmpc-dev \
+  meson
 echo
 
 echo Installing PC/WIN64 dependencies...
