@@ -27,7 +27,6 @@ Copyright_License {
 #include "java/Object.hxx"
 #include "java/Class.hxx"
 #include "java/String.hxx"
-#include "system/Path.hpp"
 
 #ifndef NO_SCREEN
 #include "ui/dim/Size.hpp"
@@ -35,6 +34,8 @@ Copyright_License {
 
 #include <cassert>
 
+class Path;
+
 class NativeView {
   JNIEnv *env;
   Java::GlobalObject obj;
@@ -51,6 +52,7 @@ class NativeView {
   static jmethodID loadResourceBitmap_method;
   static jmethodID loadFileBitmap_method;
   static jmethodID bitmapToTexture_method;
+  static jmethodID shareText_method;
   static jmethodID openWaypointFile_method;
   static jmethodID getNetState_method;
 
@@ -145,6 +147,12 @@ public:
     env->SetStaticBooleanField(cls, textureNonPowerOfTwo_field, value);
   }
 
+  /**
+   * Deliver plain text data to somebody; the user will be asked to
+   * pick a recipient.
+   */
+  void ShareText(const char *text) noexcept;
+
   void OpenWaypointFile(unsigned id, const char *filename) {
     env->CallVoidMethod(obj, openWaypointFile_method, id,
                         Java::String(env, filename).Get());
