@@ -25,7 +25,6 @@ Copyright_License {
 #define XCSOAR_ANDROID_TEXT_UTIL_HPP
 
 #include "java/Object.hxx"
-#include "util/Compiler.h"
 
 #include <utility>
 
@@ -47,10 +46,9 @@ public:
   static void Initialise(JNIEnv *env) noexcept;
   static void Deinitialise(JNIEnv *env) noexcept;
 
-  gcc_malloc
   static TextUtil *create(const FontDescription &d) noexcept;
 
-  gcc_pure
+  [[gnu::pure]]
   PixelSize getTextBounds(StringView text) const noexcept;
 
   struct Texture {
