@@ -23,35 +23,34 @@ Copyright_License {
 
 #include "ToneSynthesiser.hpp"
 #include "Math/FastTrig.hpp"
-#include "util/Macros.hpp"
 
 #include <cassert>
 
 void
 ToneSynthesiser::SetTone(unsigned tone_hz)
 {
-  increment = ARRAY_SIZE(ISINETABLE) * tone_hz / sample_rate;
+  increment = ISINETABLE.size() * tone_hz / sample_rate;
 }
 
 void
 ToneSynthesiser::Synthesise(int16_t *buffer, size_t n)
 {
-  assert(angle < ARRAY_SIZE(ISINETABLE));
+  assert(angle < ISINETABLE.size());
 
   for (int16_t *end = buffer + n; buffer != end; ++buffer) {
     *buffer = ISINETABLE[angle] * (32767 / 1024) * (int)volume / 100;
-    angle = (angle + increment) & (ARRAY_SIZE(ISINETABLE) - 1);
+    angle = (angle + increment) & (ISINETABLE.size() - 1);
   }
 }
 
 unsigned
 ToneSynthesiser::ToZero() const
 {
-  assert(angle < ARRAY_SIZE(ISINETABLE));
+  assert(angle < ISINETABLE.size());
 
   if (angle < increment)
     /* close enough */
     return 0;
 
-  return (ARRAY_SIZE(ISINETABLE) - angle) / increment;
+  return (ISINETABLE.size() - angle) / increment;
 }
