@@ -31,6 +31,7 @@ Copyright_License {
 #include "NMEA/InputLine.hpp"
 #include "Units/System.hpp"
 #include "Waypoint/Waypoint.hpp"
+#include "util/ConvertString.hpp"
 #include "util/TruncateString.hpp"
 #include "util/Macros.hpp"
 #include "time/TimeoutClock.hpp"
@@ -39,9 +40,6 @@ Copyright_License {
 #include <string.h>
 #include <cassert>
 #include <tchar.h>
-#ifdef _UNICODE
-#include <stringapiset.h>
-#endif
 
 #define DECELWPNAMESIZE   24                        // max size of taskpoint name
 #define DECELWPSIZE       DECELWPNAMESIZE + 25      // max size of WP declaration
@@ -50,13 +48,15 @@ class AltairProDevice : public AbstractDevice {
 private:
   Port &port;
 
-  bool DeclareInternal(const struct Declaration &declaration,
-                       OperationEnvironment &env);
-  void PutTurnPoint(const TCHAR *name, const Waypoint *waypoint,
+  void PutTurnPoint(const char *name, const Waypoint *waypoint,
                     OperationEnvironment &env);
-  bool PropertySetGet(char *Buffer, size_t size, OperationEnvironment &env);
+  bool PropertySetGet(const char *name, const char *value,
+                      char *Buffer, std::size_t size,
+                      OperationEnvironment &env);
 #ifdef _UNICODE
-  bool PropertySetGet(TCHAR *Buffer, size_t size, OperationEnvironment &env);
+  bool PropertySetGet(const char *name, const TCHAR *value,
+                      char *Buffer, std::size_t size,
+                      OperationEnvironment &env);
 #endif
 
 public:
@@ -147,30 +147,18 @@ AltairProDevice::Declare(const struct Declaration &declaration,
 {
   port.StopRxThread();
 
-  bool result = DeclareInternal(declaration, env);
+  char Buffer[256];
 
-  return result;
-}
-
-bool
-AltairProDevice::DeclareInternal(const struct Declaration &declaration,
-                                 OperationEnvironment &env)
-{
-  TCHAR Buffer[256];
-
-  StringFormatUnsafe(Buffer, _T("PDVSC,S,Pilot,%s"),
-                     declaration.pilot_name.c_str());
-  if (!PropertySetGet(Buffer, ARRAY_SIZE(Buffer), env))
+  if (!PropertySetGet("Pilot", declaration.pilot_name.c_str(),
+                      Buffer, ARRAY_SIZE(Buffer), env))
     return false;
 
-  StringFormatUnsafe(Buffer, _T("PDVSC,S,GliderID,%s"),
-                     declaration.aircraft_registration.c_str());
-  if (!PropertySetGet(Buffer, ARRAY_SIZE(Buffer), env))
+  if (!PropertySetGet("GliderID", declaration.aircraft_registration.c_str(),
+                      Buffer, ARRAY_SIZE(Buffer), env))
     return false;
 
-  StringFormatUnsafe(Buffer, _T("PDVSC,S,GliderType,%s"),
-                     declaration.aircraft_type.c_str());
-  if (!PropertySetGet(Buffer, ARRAY_SIZE(Buffer), env))
+  if (!PropertySetGet("GliderType", declaration.aircraft_type.c_str(),
+                      Buffer, ARRAY_SIZE(Buffer), env))
     return false;
 
   /* TODO currently not supported by XCSOAR
@@ -183,15 +171,15 @@ AltairProDevice::DeclareInternal(const struct Declaration &declaration,
    */
 
   if (declaration.Size() > 1) {
-    PutTurnPoint(_T("DeclTakeoff"), nullptr, env);
-    PutTurnPoint(_T("DeclLanding"), nullptr, env);
+    PutTurnPoint("DeclTakeoff", nullptr, env);
+    PutTurnPoint("DeclLanding", nullptr, env);
 
-    PutTurnPoint(_T("DeclStart"), &declaration.GetFirstWaypoint(), env);
-    PutTurnPoint(_T("DeclFinish"), &declaration.GetLastWaypoint(), env);
+    PutTurnPoint("DeclStart", &declaration.GetFirstWaypoint(), env);
+    PutTurnPoint("DeclFinish", &declaration.GetLastWaypoint(), env);
 
     for (unsigned int index=1; index <= 10; index++){
-      TCHAR TurnPointPropertyName[32];
-      StringFormatUnsafe(TurnPointPropertyName, _T("DeclTurnPoint%d"), index);
+      char TurnPointPropertyName[32];
+      StringFormatUnsafe(TurnPointPropertyName, "DeclTurnPoint%d", index);
 
       if (index < declaration.Size() - 1) {
         PutTurnPoint(TurnPointPropertyName, &declaration.GetWaypoint(index),
@@ -202,11 +190,11 @@ AltairProDevice::DeclareInternal(const struct Declaration &declaration,
     }
   }
 
-  UnsafeCopyString(Buffer, _T("PDVSC,S,DeclAction,DECLARE"));
-  if (!PropertySetGet(Buffer, ARRAY_SIZE(Buffer), env))
+  if (!PropertySetGet("DeclAction", "DECLARE",
+                      Buffer, ARRAY_SIZE(Buffer), env))
     return false;
 
-  if (StringIsEqual(&Buffer[9], _T("LOCKED")))
+  if (StringIsEqual(&Buffer[9], "LOCKED"))
     // FAILED! try to declare a task on a airborn recorder
     return false;
 
@@ -220,7 +208,8 @@ AltairProDevice::DeclareInternal(const struct Declaration &declaration,
 
 
 bool
-AltairProDevice::PropertySetGet(char *Buffer, size_t size,
+AltairProDevice::PropertySetGet(const char *name, const char *value,
+                                char *Buffer, std::size_t size,
                                 OperationEnvironment &env)
 {
   assert(Buffer != nullptr);
@@ -230,26 +219,19 @@ AltairProDevice::PropertySetGet(char *Buffer, size_t size,
   TimeoutClock timeout(std::chrono::seconds(5));
 
   // eg $PDVSC,S,FOO,BAR*<cr>\r\n
-  if (!PortWriteNMEA(port, Buffer, env))
-    return false;
-
-  Buffer[6] = _T('A');
-  char *comma = strchr(&Buffer[8], ',');
-
-  if (comma == nullptr)
-    return false;
-
-  comma[1] = '\0';
+  char buffer[1024];
+  StringFormat(buffer, std::size(buffer),
+               "PDVSC,S,%s,%s", name, value);
+  PortWriteNMEA(port, Buffer, env);
 
   // expect eg $PDVSC,A,FOO,
-  if (!port.ExpectString(Buffer, env, timeout.GetRemainingOrZero()))
-    return false;
+  port.ExpectString("PDVSC,A,", env, timeout.GetRemainingOrZero());
+  port.ExpectString(name, env, timeout.GetRemainingOrZero());
+  port.ExpectString(",", env, timeout.GetRemainingOrZero());
 
   // read value eg bar
   while (size > 0) {
     const size_t nbytes = port.WaitAndRead(Buffer, size, env, timeout);
-    if (nbytes == 0)
-      return false;
 
     char *asterisk = (char *)memchr(Buffer, '*', nbytes);
     if (asterisk != nullptr) {
@@ -265,43 +247,35 @@ AltairProDevice::PropertySetGet(char *Buffer, size_t size,
 
 #ifdef _UNICODE
 bool
-AltairProDevice::PropertySetGet(TCHAR *s, size_t size,
+AltairProDevice::PropertySetGet(const char *name, const TCHAR *_value,
+                                char *Buffer, std::size_t size,
                                 OperationEnvironment &env)
 {
-  assert(s != nullptr);
-
-  char buffer[4096];
-  if (::WideCharToMultiByte(CP_ACP, 0, s, -1, buffer, sizeof(buffer),
-                               nullptr, nullptr) <= 0)
-    return false;
-
-  if (!PropertySetGet(buffer, _tcslen(s) * 4 + 1, env))
-    return false;
-
-  if (::MultiByteToWideChar(CP_ACP, 0, buffer, -1, s, size) <= 0)
-    return false;
-
-  return true;
+  const WideToACPConverter value{_value};
+  if (!value.IsValid())
+    throw std::runtime_error("Invalid string");
 
+  return PropertySetGet(name, value, Buffer, size, env);
 }
 #endif
 
 void
-AltairProDevice::PutTurnPoint(const TCHAR *propertyName,
+AltairProDevice::PutTurnPoint(const char *propertyName,
                               const Waypoint *waypoint,
                               OperationEnvironment &env)
 {
-
-  TCHAR Name[DECELWPNAMESIZE];
-  TCHAR Buffer[DECELWPSIZE*2];
+  char Name[DECELWPNAMESIZE];
+  char Buffer[DECELWPSIZE*2];
 
   int DegLat, DegLon;
   double tmp, MinLat, MinLon;
   char NoS, EoW;
 
   if (waypoint != nullptr){
-
-    CopyTruncateString(Name, ARRAY_SIZE(Name), waypoint->name.c_str());
+    if (WideToACPConverter wp_name{waypoint->name.c_str()}; wp_name.IsValid())
+      CopyTruncateString(Name, ARRAY_SIZE(Name), wp_name);
+    else
+      throw std::runtime_error("Invalid string");
 
     tmp = (double)waypoint->location.latitude.Degrees();
 
@@ -338,11 +312,11 @@ AltairProDevice::PutTurnPoint(const TCHAR *propertyName,
     EoW = 'E';
   }
 
-  StringFormatUnsafe(Buffer, _T("PDVSC,S,%s,%02d%05.0f%c%03d%05.0f%c%s"),
-                     propertyName,
+  StringFormatUnsafe(Buffer, "%02d%05.0f%c%03d%05.0f%c%s",
                      DegLat, MinLat, NoS, DegLon, MinLon, EoW, Name);
 
-  PropertySetGet(Buffer, ARRAY_SIZE(Buffer), env);
+  PropertySetGet(propertyName, Buffer,
+                 Buffer, ARRAY_SIZE(Buffer), env);
 
 }
 
