@@ -44,7 +44,8 @@ FlymasterF1Device::EnableNMEA(OperationEnvironment &env)
 {
   /* this command initiates NMEA mode according to the "Flymaster F1
      Commands" document */
-  return PortWriteNMEA(port, "$PFMNAV,", env);
+  PortWriteNMEA(port, "$PFMNAV,", env);
+  return true;
 }
 
 static bool
