@@ -35,7 +35,7 @@ class PortLineSplitter : public DataHandler, protected PortLineHandler {
 
 public:
   /* virtual methods from class DataHandler */
-  bool DataReceived(const void *data, size_t length) noexcept override;
+  bool DataReceived(std::span<const std::byte> s) noexcept override;
 };
 
 #endif
