@@ -91,6 +91,8 @@ static constexpr StaticEnumChoice info_box_geometry_list[] = {
     N_("12 Split in 3 rows") },
   { (unsigned)InfoBoxSettings::Geometry::SPLIT_3X5,
     N_("15 Split in 3 rows") },
+  { (unsigned)InfoBoxSettings::Geometry::SPLIT_3X6,
+    N_("18 Split in 3 rows") },
   { (unsigned)InfoBoxSettings::Geometry::BOTTOM_RIGHT_8,
     N_("8 Bottom or Right") },
   { (unsigned)InfoBoxSettings::Geometry::BOTTOM_8_VARIO,
