@@ -2,7 +2,7 @@
 Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -26,7 +26,7 @@ Copyright_License {
 
 class Widget;
 
-Widget *
+std::unique_ptr<Widget>
 CreateTaskDefaultsConfigPanel();
 
 #endif /* TASKDEFAULTSCONFIGPANEL_HPP */
