@@ -41,23 +41,23 @@ public:
   void Create(ContainerWindow &parent, const ButtonLook &look,
               const TCHAR *text, PixelRect rc,
               OnCharacterCallback on_character, unsigned character,
-              const WindowStyle _style=WindowStyle());
+              const WindowStyle _style=WindowStyle()) noexcept;
 
-  unsigned GetCharacter() const {
+  unsigned GetCharacter() const noexcept {
     return character;
   }
 
   /**
    * Convert GetCharacter() to upper case (ASCII only).
    */
-  gcc_pure
-  unsigned GetUpperCharacter() const;
+  [[gnu::pure]]
+  unsigned GetUpperCharacter() const noexcept;
 
-  void SetCharacter(unsigned character);
+  void SetCharacter(unsigned character) noexcept;
 
 protected:
   /* virtual methods from class ButtonWindow */
-  virtual bool OnClicked();
+  bool OnClicked() noexcept override;
 };
 
 #endif
