@@ -405,9 +405,10 @@ FlarmTrafficWindow::PaintRadarTarget(Canvas &canvas,
   }
 
   // Rotate and shift the arrow
-  PolygonRotateShift(Arrow, 4, sc[i],
+  PolygonRotateShift(Arrow, sc[i],
                      traffic.track - (enable_north_up ?
-                                             Angle::Zero() : heading));
+                                      Angle::Zero() : heading),
+                     Layout::Scale(100u));
 
   // Select pen and brush
   canvas.Select(*target_pen);
