@@ -209,10 +209,15 @@ void
 InfoBoxContentWindArrow::OnCustomPaint(Canvas &canvas,
                                        const PixelRect &rc) noexcept
 {
+  constexpr unsigned arrow_width = 6;
+  constexpr unsigned arrow_tail_length = 3;
+
   const auto &info = CommonInterface::Calculated();
 
   const auto pt = rc.GetCenter();
 
+  const unsigned scale = Layout::Scale(100U);
+
   const unsigned padding = Layout::FastScale(10u);
   unsigned size = std::min(rc.GetWidth(), rc.GetHeight());
 
@@ -221,7 +226,7 @@ InfoBoxContentWindArrow::OnCustomPaint(Canvas &canvas,
 
   // Normalize the size because the Layout::Scale is applied
   // by the DrawArrow() function again
-  size = size * 100 / Layout::Scale(100);
+  size = size * 100 / scale;
 
   auto angle = info.wind.bearing - CommonInterface::Basic().attitude.heading;
 
@@ -233,5 +238,7 @@ InfoBoxContentWindArrow::OnCustomPaint(Canvas &canvas,
   auto style = CommonInterface::GetMapSettings().wind_arrow_style;
 
   WindArrowRenderer renderer(UIGlobals::GetLook().wind_arrow_info_box);
-  renderer.DrawArrow(canvas, pt, angle, length, style, offset);
+  renderer.DrawArrow(canvas, pt, angle,
+                     arrow_width, length, arrow_tail_length,
+                     style, offset, scale);
 }
