@@ -2,7 +2,7 @@
   Copyright_License {
 
   XCSoar Glide Computer - http://www.xcsoar.org/
-  Copyright (C) 2000-2015 The XCSoar Project
+  Copyright (C) 2000-2021 The XCSoar Project
   A detailed list of copyright holders can be found in the file "AUTHORS".
 
   This program is free software; you can redistribute it and/or
@@ -24,7 +24,7 @@
 #ifndef XCSOAR_NOAA_LOOK_HPP
 #define XCSOAR_NOAA_LOOK_HPP
 
-#include "Screen/Icon.hpp"
+#include "ui/canvas/Icon.hpp"
 
 struct NOAALook {
   MaskedIcon icon;
