@@ -45,6 +45,7 @@ Copyright_License {
 #include "Look/DefaultFonts.hpp"
 #include "Look/Look.hpp"
 #include "Operation/PopupOperationEnvironment.hpp"
+#include "Operation/PluggableOperationEnvironment.hpp"
 #include "Device/MultipleDevices.hpp"
 #include "ProgressGlue.hpp"
 #include "UIState.hpp"
@@ -68,9 +69,9 @@ Copyright_License {
 static constexpr unsigned separator_height = 2;
 
 #ifdef HAVE_SHOW_MENU_BUTTON
-gcc_pure
+[[gnu::pure]]
 static PixelRect
-GetShowMenuButtonRect(const PixelRect rc)
+GetShowMenuButtonRect(const PixelRect rc) noexcept
 {
   const unsigned padding = Layout::GetTextPadding();
   const unsigned size = Layout::GetMaximumControlHeight();
@@ -83,9 +84,36 @@ GetShowMenuButtonRect(const PixelRect rc)
 }
 #endif
 
-gcc_pure
+[[gnu::pure]]
 static PixelRect
-GetBottomWidgetRect(const PixelRect &rc, const Widget *bottom_widget)
+GetTopWidgetRect(const PixelRect &rc, const Widget *top_widget) noexcept
+{
+  if (top_widget == nullptr) {
+    /* no top widget: return empty rectangle, map uses the whole main
+       area */
+    PixelRect result = rc;
+    result.bottom = result.top;
+    return result;
+  }
+
+  const unsigned requested_height = top_widget->GetMinimumSize().height;
+  unsigned height;
+  if (requested_height > 0) {
+    const unsigned max_height = rc.GetHeight() / 2;
+    height = std::min(max_height, requested_height);
+  } else {
+    const unsigned recommended_height = rc.GetHeight() / 4;
+    height = recommended_height;
+  }
+
+  PixelRect result = rc;
+  result.bottom = result.top + height;
+  return result;
+}
+
+[[gnu::pure]]
+static PixelRect
+GetBottomWidgetRect(const PixelRect &rc, const Widget *bottom_widget) noexcept
 {
   if (bottom_widget == nullptr) {
     /* no bottom widget: return empty rectangle, map uses the whole
@@ -110,9 +138,9 @@ GetBottomWidgetRect(const PixelRect &rc, const Widget *bottom_widget)
   return result;
 }
 
-gcc_pure
+[[gnu::pure]]
 static PixelRect
-GetMapRectAbove(const PixelRect &rc, const PixelRect &bottom_rect)
+GetMapRectAbove(const PixelRect &rc, const PixelRect &bottom_rect) noexcept
 {
   PixelRect result = rc;
   result.bottom = bottom_rect.top;
@@ -121,11 +149,22 @@ GetMapRectAbove(const PixelRect &rc, const PixelRect &bottom_rect)
   return result;
 }
 
+[[gnu::pure]]
+static PixelRect
+GetMapRectBelow(const PixelRect &rc, const PixelRect &top_rect) noexcept
+{
+  PixelRect result = rc;
+  result.top = top_rect.bottom;
+  if (top_rect.top < top_rect.bottom)
+    result.top += separator_height;
+  return result;
+}
+
 /**
  * Destructor of the MainWindow-Class
  * @return
  */
-MainWindow::~MainWindow()
+MainWindow::~MainWindow() noexcept
 {
   Destroy();
 }
@@ -138,7 +177,7 @@ MainWindow::Create(PixelSize size, UI::TopWindowStyle style)
 
 [[noreturn]]
 static void
-FatalError(const TCHAR *msg)
+FatalError(const TCHAR *msg) noexcept
 {
 #if defined(HAVE_POSIX) && defined(NDEBUG)
   /* make sure this gets written to stderr in any case; LogFormat()
@@ -161,7 +200,7 @@ FatalError(const TCHAR *msg)
 
 [[noreturn]]
 static void
-NoFontsAvailable()
+NoFontsAvailable() noexcept
 {
   FatalError(_T("Font initialisation failed"));
 }
@@ -242,7 +281,7 @@ MainWindow::InitialiseConfigured()
 }
 
 void
-MainWindow::Deinitialise()
+MainWindow::Deinitialise() noexcept
 {
   InfoBoxManager::Destroy();
   ButtonLabel::Destroy();
@@ -271,7 +310,7 @@ MainWindow::Deinitialise()
 }
 
 void
-MainWindow::ReinitialiseLayout_vario(const InfoBoxLayout::Layout &layout)
+MainWindow::ReinitialiseLayout_vario(const InfoBoxLayout::Layout &layout) noexcept
 {
   if (!layout.HasVario()) {
     vario.Clear();
@@ -290,7 +329,7 @@ MainWindow::ReinitialiseLayout_vario(const InfoBoxLayout::Layout &layout)
 
 void
 MainWindow::ReinitialiseLayoutTA(PixelRect rc,
-                                 const InfoBoxLayout::Layout &layout)
+                                 const InfoBoxLayout::Layout &layout) noexcept
 {
   unsigned sz = std::min(layout.control_size.height,
                          layout.control_size.width) * 2;
@@ -314,13 +353,13 @@ MainWindow::ReinitialiseLayoutTA(PixelRect rc,
     rc.left = GetMainRect().left;
     rc.right = rc.left + sz;
     break;
-  } 
+  }
   rc.top = rc.bottom - sz;
   thermal_assistant.Move(rc);
 }
 
 void
-MainWindow::ReinitialiseLayout()
+MainWindow::ReinitialiseLayout() noexcept
 {
   if (map == nullptr)
     /* without the MapWindow, it is safe to assume that the MainWindow
@@ -363,7 +402,14 @@ MainWindow::ReinitialiseLayout()
     else
       InfoBoxManager::Show();
 
-    const PixelRect main_rect = GetMainRect();
+    PixelRect main_rect = GetMainRect();
+    const PixelRect top_rect = GetTopWidgetRect(main_rect,
+                                                top_widget);
+    main_rect = GetMapRectBelow(main_rect, top_rect);
+
+    if (HaveTopWidget())
+      top_widget->Move(top_rect);
+
     const PixelRect bottom_rect = GetBottomWidgetRect(main_rect,
                                                       bottom_widget);
 
@@ -386,9 +432,9 @@ MainWindow::ReinitialiseLayout()
     map->BringToBottom();
 }
 
-void 
+void
 MainWindow::ReinitialiseLayout_flarm(PixelRect rc,
-                                     const InfoBoxLayout::Layout &ib_layout)
+                                     const InfoBoxLayout::Layout &ib_layout) noexcept
 {
   TrafficSettings::GaugeLocation val =
     CommonInterface::GetUISettings().traffic.gauge_location;
@@ -453,7 +499,7 @@ MainWindow::ReinitialiseLayout_flarm(PixelRect rc,
 }
 
 void
-MainWindow::Destroy()
+MainWindow::Destroy() noexcept
 {
   Deinitialise();
 
@@ -461,7 +507,7 @@ MainWindow::Destroy()
 }
 
 void
-MainWindow::FinishStartup()
+MainWindow::FinishStartup() noexcept
 {
   timer.Schedule(std::chrono::milliseconds(500)); // 2 times per second
 
@@ -469,29 +515,30 @@ MainWindow::FinishStartup()
 }
 
 void
-MainWindow::BeginShutdown()
+MainWindow::BeginShutdown() noexcept
 {
   timer.Cancel();
 
+  KillTopWidget();
   KillBottomWidget();
 }
 
 void
-MainWindow::SuspendThreads()
+MainWindow::SuspendThreads() noexcept
 {
   if (map != nullptr)
     map->SuspendThreads();
 }
 
 void
-MainWindow::ResumeThreads()
+MainWindow::ResumeThreads() noexcept
 {
   if (map != nullptr)
     map->ResumeThreads();
 }
 
 void
-MainWindow::SetDefaultFocus()
+MainWindow::SetDefaultFocus() noexcept
 {
   if (map != nullptr && widget == nullptr)
     map->SetFocus();
@@ -500,14 +547,14 @@ MainWindow::SetDefaultFocus()
 }
 
 void
-MainWindow::FlushRendererCaches()
+MainWindow::FlushRendererCaches() noexcept
 {
   if (map != nullptr)
     map->FlushCaches();
 }
 
 void
-MainWindow::FullRedraw()
+MainWindow::FullRedraw() noexcept
 {
   if (map != nullptr)
     map->FullRedraw();
@@ -550,7 +597,7 @@ MainWindow::OnSetFocus()
 }
 
 void
-MainWindow::StopDragging()
+MainWindow::StopDragging() noexcept
 {
   if (!dragging)
     return;
@@ -627,6 +674,7 @@ bool
 MainWindow::OnKeyDown(unsigned key_code)
 {
   return (widget != nullptr && widget->KeyPress(key_code)) ||
+    (HaveTopWidget() && top_widget->KeyPress(key_code)) ||
     (HaveBottomWidget() && bottom_widget->KeyPress(key_code)) ||
     InputEvents::processKey(key_code) ||
     SingleWindow::OnKeyDown(key_code);
@@ -710,6 +758,7 @@ MainWindow::OnDestroy()
   timer.Cancel();
 
   KillWidget();
+  KillTopWidget();
   KillBottomWidget();
 
   SingleWindow::OnDestroy();
@@ -744,7 +793,7 @@ MainWindow::OnPaint(Canvas &canvas)
 }
 
 void
-MainWindow::SetFullScreen(bool _full_screen)
+MainWindow::SetFullScreen(bool _full_screen) noexcept
 {
   if (_full_screen == FullScreen)
     return;
@@ -768,35 +817,35 @@ MainWindow::SetFullScreen(bool _full_screen)
 }
 
 void
-MainWindow::SetTerrain(RasterTerrain *terrain)
+MainWindow::SetTerrain(RasterTerrain *terrain) noexcept
 {
   if (map != nullptr)
     map->SetTerrain(terrain);
 }
 
 void
-MainWindow::SetTopography(TopographyStore *topography)
+MainWindow::SetTopography(TopographyStore *topography) noexcept
 {
   if (map != nullptr)
     map->SetTopography(topography);
 }
 
 void
-MainWindow::SetComputerSettings(const ComputerSettings &settings_computer)
+MainWindow::SetComputerSettings(const ComputerSettings &settings_computer) noexcept
 {
   if (map != nullptr)
     map->SetComputerSettings(settings_computer);
 }
 
 void
-MainWindow::SetMapSettings(const MapSettings &settings_map)
+MainWindow::SetMapSettings(const MapSettings &settings_map) noexcept
 {
   if (map != nullptr)
     map->SetMapSettings(settings_map);
 }
 
 void
-MainWindow::SetUIState(const UIState &ui_state)
+MainWindow::SetUIState(const UIState &ui_state) noexcept
 {
   if (map != nullptr) {
     map->SetUIState(ui_state);
@@ -805,13 +854,13 @@ MainWindow::SetUIState(const UIState &ui_state)
 }
 
 GlueMapWindow *
-MainWindow::GetMapIfActive()
+MainWindow::GetMapIfActive() noexcept
 {
   return IsMapActive() ? map : nullptr;
 }
 
 GlueMapWindow *
-MainWindow::ActivateMap()
+MainWindow::ActivateMap() noexcept
 {
   restore_page_pending = false;
 
@@ -841,7 +890,7 @@ MainWindow::ActivateMap()
 }
 
 void
-MainWindow::DeferredRestorePage()
+MainWindow::DeferredRestorePage() noexcept
 {
   if (restore_page_pending)
     return;
@@ -851,7 +900,7 @@ MainWindow::DeferredRestorePage()
 }
 
 void
-MainWindow::KillWidget()
+MainWindow::KillWidget() noexcept
 {
   if (widget == nullptr)
     return;
@@ -866,7 +915,50 @@ MainWindow::KillWidget()
 }
 
 void
-MainWindow::KillBottomWidget()
+MainWindow::KillTopWidget() noexcept
+{
+  if (top_widget == nullptr)
+    return;
+
+  top_widget->Hide();
+  top_widget->Unprepare();
+  delete top_widget;
+  top_widget = nullptr;
+}
+
+void
+MainWindow::SetTopWidget(Widget *_widget) noexcept
+{
+  if (top_widget == nullptr && _widget == nullptr)
+    return;
+
+  KillTopWidget();
+
+  top_widget = _widget;
+
+  PixelRect main_rect = GetMainRect();
+  const PixelRect top_rect = GetTopWidgetRect(main_rect,
+                                              top_widget);
+  if (top_widget != nullptr) {
+    top_widget->Initialise(*this, top_rect);
+    top_widget->Prepare(*this, top_rect);
+    top_widget->Show(top_rect);
+  }
+
+  main_rect = GetMapRectBelow(main_rect, top_rect);
+
+  const PixelRect bottom_rect = GetBottomWidgetRect(main_rect,
+                                                    bottom_widget);
+
+  if (HaveBottomWidget())
+    bottom_widget->Move(bottom_rect);
+
+  map->Move(GetMapRectAbove(main_rect, bottom_rect));
+  map->FullRedraw();
+}
+
+void
+MainWindow::KillBottomWidget() noexcept
 {
   if (bottom_widget == nullptr)
     return;
@@ -882,7 +974,7 @@ MainWindow::KillBottomWidget()
 }
 
 void
-MainWindow::SetBottomWidget(Widget *_widget)
+MainWindow::SetBottomWidget(Widget *_widget) noexcept
 {
   if (bottom_widget == nullptr && _widget == nullptr)
     return;
@@ -897,7 +989,13 @@ MainWindow::SetBottomWidget(Widget *_widget)
 
   bottom_widget = _widget;
 
-  const PixelRect main_rect = GetMainRect();
+  PixelRect main_rect = GetMainRect();
+  const PixelRect top_rect = GetTopWidgetRect(main_rect,
+                                              top_widget);
+  main_rect = GetMapRectBelow(main_rect, top_rect);
+  if (HaveTopWidget())
+    top_widget->Move(top_rect);
+
   const PixelRect bottom_rect = GetBottomWidgetRect(main_rect,
                                                     bottom_widget);
 
@@ -916,7 +1014,7 @@ MainWindow::SetBottomWidget(Widget *_widget)
 }
 
 void
-MainWindow::SetWidget(Widget *_widget)
+MainWindow::SetWidget(Widget *_widget) noexcept
 {
   assert(_widget != nullptr);
 
@@ -954,7 +1052,7 @@ MainWindow::SetWidget(Widget *_widget)
 }
 
 Widget *
-MainWindow::GetFlavourWidget(const TCHAR *flavour)
+MainWindow::GetFlavourWidget(const TCHAR *flavour) noexcept
 {
   return InputEvents::IsFlavour(flavour)
     ? widget
@@ -962,7 +1060,7 @@ MainWindow::GetFlavourWidget(const TCHAR *flavour)
 }
 
 void
-MainWindow::UpdateVarioGaugeVisibility()
+MainWindow::UpdateVarioGaugeVisibility() noexcept
 {
   bool full_screen = GetFullScreen();
 
@@ -971,14 +1069,14 @@ MainWindow::UpdateVarioGaugeVisibility()
 }
 
 void
-MainWindow::UpdateGaugeVisibility()
+MainWindow::UpdateGaugeVisibility() noexcept
 {
   UpdateVarioGaugeVisibility();
   UpdateTrafficGaugeVisibility();
 }
 
 void
-MainWindow::UpdateTrafficGaugeVisibility()
+MainWindow::UpdateTrafficGaugeVisibility() noexcept
 {
   const FlarmData &flarm = CommonInterface::Basic().flarm;
 
@@ -1018,7 +1116,7 @@ MainWindow::UpdateTrafficGaugeVisibility()
 }
 
 const MapWindowProjection &
-MainWindow::GetProjection() const
+MainWindow::GetProjection() const noexcept
 {
   AssertThread();
   assert(map != nullptr);
@@ -1027,13 +1125,13 @@ MainWindow::GetProjection() const
 }
 
 void
-MainWindow::ToggleSuppressFLARMRadar()
+MainWindow::ToggleSuppressFLARMRadar() noexcept
 {
   suppress_traffic_gauge = !suppress_traffic_gauge;
 }
 
 void
-MainWindow::ToggleForceFLARMRadar()
+MainWindow::ToggleForceFLARMRadar() noexcept
 {
   force_traffic_gauge = !force_traffic_gauge;
   CommonInterface::SetUISettings().traffic.enable_gauge = force_traffic_gauge;
