@@ -26,10 +26,10 @@ Copyright_License {
 void
 MapWindow::DrawWaypoints(Canvas &canvas)
 {
-  waypoint_renderer.render(canvas, label_block,
-                            render_projection, GetMapSettings().waypoint,
+  waypoint_renderer.Render(canvas, label_block,
+                           render_projection, GetMapSettings().waypoint,
                            GetComputerSettings().polar,
-                            GetComputerSettings().task,
+                           GetComputerSettings().task,
                            Basic(), Calculated(),
-                            task, route_planner);
+                           task, route_planner);
 }
