@@ -28,6 +28,7 @@ Copyright_License {
 #include <cmath>
 
 template<typename T, typename PT=T>
+requires(std::is_arithmetic_v<T> && std::is_arithmetic_v<PT>)
 struct Point2D {
   using scalar_type = T;
 
@@ -126,58 +127,48 @@ struct FloatPoint2D : Point2D<float> {
 static_assert(std::is_trivial<FloatPoint2D>::value, "type is not trivial");
 
 template<typename P>
-using IsPoint2D = std::is_base_of<Point2D<typename P::scalar_type,
-                                          typename P::product_type>, P>;
+concept AnyPoint2D = std::is_base_of_v<Point2D<typename P::scalar_type,
+                                               typename P::product_type>,
+                                       P>;
 
-template<typename P>
-using EnableIfPoint2D = std::enable_if_t<IsPoint2D<P>::value>;
-
-template<typename P, typename RT=typename P::product_type,
-         typename=EnableIfPoint2D<P>>
+template<AnyPoint2D P, typename RT=typename P::product_type>
 constexpr P
 operator+(P a, P b) noexcept
 {
   return P(a.x + b.x, a.y + b.y);
 }
 
-template<typename P, typename RT=typename P::product_type,
-         typename=EnableIfPoint2D<P>>
+template<AnyPoint2D P>
 constexpr P
 operator-(P a, P b) noexcept
 {
   return P(a.x - b.x, a.y - b.y);
 }
 
-template<typename P, typename RT=typename P::product_type,
-         typename=EnableIfPoint2D<P>,
-         typename Z,
-         typename=std::enable_if_t<std::is_arithmetic<Z>::value>>
+template<AnyPoint2D P, typename Z>
+requires(std::is_arithmetic_v<Z>)
 constexpr P
 operator*(P a, Z z) noexcept
 {
   return P(a.x * z, a.y * z);
 }
 
-template<typename P, typename RT=typename P::product_type,
-         typename=EnableIfPoint2D<P>,
-         typename Z,
-         typename=std::enable_if_t<std::is_arithmetic<Z>::value>>
+template<AnyPoint2D P, typename Z>
+requires(std::is_arithmetic_v<Z>)
 constexpr P
 operator/(P a, Z z) noexcept
 {
   return P(a.x / z, a.y / z);
 }
 
-template<typename P, typename RT=typename P::product_type,
-         typename=EnableIfPoint2D<P>>
+template<AnyPoint2D P, typename RT=typename P::product_type>
 constexpr RT
 DotProduct(P a, P b) noexcept
 {
   return RT(a.x) * RT(b.x) + RT(a.y) * RT(b.y);
 }
 
-template<typename P, typename RT=typename P::product_type,
-         typename=EnableIfPoint2D<P>>
+template<AnyPoint2D P, typename RT=typename P::product_type>
 constexpr RT
 CrossProduct(P a, P b) noexcept
 {
@@ -187,8 +178,7 @@ CrossProduct(P a, P b) noexcept
 /**
  * Calculates the "manhattan distance" or "taxicab distance".
  */
-template<typename P, typename RT=typename P::scalar_type,
-         typename=EnableIfPoint2D<P>>
+template<AnyPoint2D P, typename RT=typename P::scalar_type>
 constexpr RT
 ManhattanDistance(P a, P b) noexcept
 {
