@@ -30,6 +30,7 @@ Copyright_License {
 
 #ifndef ENABLE_OPENGL
 #include "TransparentRendererCache.hpp"
+#include "util/Serial.hpp"
 #endif
 
 struct AirspaceLook;
@@ -47,8 +48,8 @@ class AirspaceRenderer
 {
   const AirspaceLook &look;
 
-  const Airspaces *airspaces;
-  const ProtectedAirspaceWarningManager *warning_manager;
+  const Airspaces *airspaces = nullptr;
+  const ProtectedAirspaceWarningManager *warning_manager = nullptr;
 
   StaticArray<GeoPoint,32> intersections;
 
@@ -59,16 +60,12 @@ class AirspaceRenderer
    */
   TransparentRendererCache fill_cache;
 
-  unsigned last_warning_serial;
+  Serial last_warning_serial;
 #endif
 
 public:
   AirspaceRenderer(const AirspaceLook &_look)
-    :look(_look), airspaces(nullptr), warning_manager(nullptr)
-#ifndef ENABLE_OPENGL
-    , last_warning_serial(0)
-#endif
-  {}
+    :look(_look) {}
 
   const AirspaceLook &GetLook() const {
     return look;
