@@ -73,6 +73,7 @@ Copyright_License {
 #include "io/async/GlobalAsioThread.hpp"
 #include "net/http/Init.hpp"
 #include "net/http/DownloadManager.hpp"
+#include "net/client/tim/Glue.hpp"
 #include "Hardware/DisplayDPI.hpp"
 #include "Hardware/DisplayGlue.hpp"
 #include "util/Compiler.h"
@@ -352,6 +353,7 @@ Startup()
   main_window->LoadTerrain();
 
   logger = new Logger();
+  nmea_logger = new NMEALogger();
 
   glide_computer = new GlideComputer(computer_settings,
                                      way_points, airspace_database,
@@ -508,7 +510,7 @@ Startup()
   }
 
   if (computer_settings.logger.enable_nmea_logger)
-    NMEALogger::enabled = true;
+    nmea_logger->Enable();
 
   LogFormat("ProgramStarted");
 
@@ -531,6 +533,12 @@ Startup()
 #endif
 #endif
 
+#ifdef HAVE_HTTP
+  tim_glue = new TIM::Glue(*Net::curl);
+  if (map_window != nullptr)
+    map_window->SetThermalInfoMap(tim_glue);
+#endif
+
   assert(!global_running);
   global_running = true;
 
@@ -666,7 +674,8 @@ Shutdown()
   // Close any device connections
   devShutdown();
 
-  NMEALogger::Shutdown();
+  delete nmea_logger;
+  nmea_logger = nullptr;
 
   delete replay;
   replay = nullptr;
@@ -690,6 +699,11 @@ Shutdown()
   noaa_store = nullptr;
 #endif
 
+#ifdef HAVE_HTTP
+  delete tim_glue;
+  tim_glue = nullptr;
+#endif
+
 #ifdef HAVE_TRACKING
   delete tracking;
   tracking = nullptr;
