@@ -23,6 +23,7 @@ Copyright_License {
 
 #include "Topography/XShape.hpp"
 #include "Convert.hpp"
+#include "util/Compiler.h"
 #include "util/StringAPI.hxx"
 #include "util/UTF8.hpp"
 #include "util/StringStrip.hxx"
@@ -86,19 +87,13 @@ GetMinPointsForShapeType(int shapelib_type) noexcept
   }
 }
 
-XShape::XShape(shapefileObj *shpfile, const GeoPoint &file_center, int i,
-               int label_field)
+XShape::XShape(const shapeObj &shape, const GeoPoint &file_center,
+               const char *_label)
+  :label(ImportLabel(_label))
 {
-  shapeObj shape;
-  msInitShape(&shape);
-  AtScopeExit(&shape) { msFreeShape(&shape); };
-  msSHPReadShape(shpfile->hSHP, i, &shape);
-
   bounds = ImportRect(shape.bounds);
-  if (!bounds.Check()) {
-    /* malformed bounds */
-    return;
-  }
+  if (!bounds.Check())
+    throw std::runtime_error{"Malformed shape bounds"};
 
   type = shape.type;
 
@@ -110,10 +105,10 @@ XShape::XShape(shapefileObj *shpfile, const GeoPoint &file_center, int i,
     return;
   }
 
-  const unsigned input_lines = std::min((unsigned)shape.numlines,
-                                        (unsigned)MAX_LINES);
-  unsigned num_points = 0;
-  for (unsigned l = 0; l < input_lines; ++l) {
+  const std::size_t input_lines = std::min((std::size_t)shape.numlines,
+                                           lines.size());
+  std::size_t num_points = 0;
+  for (std::size_t l = 0; l < input_lines; ++l) {
     if (shape.line[l].numpoints < min_points)
       /* malformed shape */
       continue;
@@ -127,18 +122,17 @@ XShape::XShape(shapefileObj *shpfile, const GeoPoint &file_center, int i,
   /* OpenGL: convert GeoPoints to ShapePoints, make them relative to
      the map's boundary center */
 
-  points = new ShapePoint[num_points];
-  ShapePoint *p = points;
+  points = std::make_unique<ShapePoint[]>(num_points);
 #else // !ENABLE_OPENGL
   /* convert all points of all lines to GeoPoints */
 
-  points = new GeoPoint[num_points];
-  GeoPoint *p = points;
+  points = std::make_unique<GeoPoint[]>(num_points);
 #endif
-  for (unsigned l = 0; l < num_lines; ++l) {
+  auto *p = points.get();
+  for (std::size_t l = 0; l < num_lines; ++l) {
     const pointObj *src = shape.line[l].point;
     num_points = lines[l];
-    for (unsigned j = 0; j < num_points; ++j, ++src) {
+    for (std::size_t j = 0; j < num_points; ++j, ++src) {
 #ifdef ENABLE_OPENGL
       const GeoPoint vertex(Angle::Degrees(src->x), Angle::Degrees(src->y));
       const GeoPoint relative = vertex - file_center;
@@ -151,22 +145,9 @@ XShape::XShape(shapefileObj *shpfile, const GeoPoint &file_center, int i,
 #endif
     }
   }
-
-  if (label_field >= 0) {
-    const char *src = msDBFReadStringAttribute(shpfile->hDBF, i, label_field);
-    label = ImportLabel(src);
-  }
 }
 
-XShape::~XShape() noexcept
-{
-  delete[] points;
-#ifdef ENABLE_OPENGL
-  // Note: index_count and indices share one buffer
-  for (auto *i : index_count)
-    delete[] i;
-#endif
-}
+XShape::~XShape() noexcept = default;
 
 #ifdef ENABLE_OPENGL
 
@@ -176,22 +157,22 @@ XShape::BuildIndices(unsigned thinning_level, ShapeScalar min_distance) noexcept
   assert(indices[thinning_level] == nullptr);
 
   uint16_t *idx, *idx_count;
-  unsigned num_points = 0;
+  std::size_t num_points = 0;
 
-  for (unsigned i=0; i < num_lines; i++)
+  for (std::size_t i=0; i < num_lines; i++)
     num_points += lines[i];
 
   if (type == MS_SHAPE_LINE) {
     if (num_points <= 2)
       return false;  // line cannot be simplified, so don't create indices
-    index_count[thinning_level] = idx_count =
-      new GLushort[num_lines + num_points];
+    index_count[thinning_level] = std::make_unique<GLushort[]>(num_lines + num_points);
+    idx_count = index_count[thinning_level].get();
     indices[thinning_level] = idx = idx_count + num_lines;
 
-    const uint16_t *end_l = lines + num_lines;
-    const ShapePoint *p = points;
+    const auto end_l = std::next(lines.begin(), num_lines);
+    const ShapePoint *p = points.get();
     unsigned i = 0;
-    for (const uint16_t *l = lines; l < end_l; l++) {
+    for (auto l = lines.begin(); l != end_l; ++l) {
       assert(*l >= 2);
       const ShapePoint *end_p = p + *l - 1;
       // always add first point
@@ -214,19 +195,19 @@ XShape::BuildIndices(unsigned thinning_level, ShapeScalar min_distance) noexcept
     // TODO: free memory saved by thinning (use malloc/realloc or some class?)
     return true;
   } else if (type == MS_SHAPE_POLYGON) {
-    index_count[thinning_level] = idx_count =
-      new GLushort[1 + 3*(num_points-2) + 2*(num_lines-1)];
+    index_count[thinning_level] = std::make_unique<GLushort[]>(1 + 3 * (num_points - 2) + 2 * (num_lines - 1));
+    idx_count = index_count[thinning_level].get();
     indices[thinning_level] = idx = idx_count + 1;
 
     *idx_count = 0;
-    const ShapePoint *pt = points;
-    for (unsigned i=0; i < num_lines; i++) {
-      unsigned count = PolygonToTriangles(pt, lines[i], idx + *idx_count,
-                                          min_distance);
+    const ShapePoint *pt = points.get();
+    for (std::size_t i=0; i < num_lines; i++) {
+      std::size_t count = PolygonToTriangles(pt, lines[i], idx + *idx_count,
+                                             min_distance);
       if (i > 0) {
-        const GLushort offset = pt - points;
-        const unsigned max_idx_count = *idx_count + count;
-        for (unsigned j=*idx_count; j < max_idx_count; j++)
+        const GLushort offset = pt - points.get();
+        const std::size_t max_idx_count = *idx_count + count;
+        for (std::size_t j = *idx_count; j < max_idx_count; j++)
           idx[j] += offset;
       }
       *idx_count += count;
@@ -249,7 +230,7 @@ XShape::GetIndices(int thinning_level, ShapeScalar min_distance) const noexcept
       return {};
   }
 
-  return {indices[thinning_level], index_count[thinning_level]};
+  return {indices[thinning_level], index_count[thinning_level].get()};
 }
 
 #endif // ENABLE_OPENGL
