@@ -214,6 +214,16 @@ ArrowPagerWidget::SetFocus() noexcept
   return true;
 }
 
+bool
+ArrowPagerWidget::HasFocus() const noexcept
+{
+  return PagerWidget::HasFocus() ||
+    previous_button.HasFocus() ||
+    next_button.HasFocus() ||
+    close_button.HasFocus() ||
+    (extra != nullptr && extra->HasFocus());
+}
+
 bool
 ArrowPagerWidget::KeyPress(unsigned key_code) noexcept
 {
