@@ -164,6 +164,12 @@ ManagedWidget::SetFocus() noexcept
   return IsVisible() && widget->SetFocus();
 }
 
+bool
+ManagedWidget::HasFocus() const noexcept
+{
+  return IsVisible() && widget->HasFocus();
+}
+
 bool
 ManagedWidget::KeyPress(unsigned key_code) noexcept
 {
