@@ -208,6 +208,12 @@ TwoWidgets::SetFocus() noexcept
   return first->SetFocus() || second->SetFocus();
 }
 
+bool
+TwoWidgets::HasFocus() const noexcept
+{
+  return first->HasFocus() || second->HasFocus();
+}
+
 bool
 TwoWidgets::KeyPress(unsigned key_code) noexcept
 {
