@@ -131,6 +131,8 @@ public:
   }
 };
 
+#ifndef GREYSCALE
+
 class MMXAlpha32PixelOperations : MMXAlphaPixelOperations {
 public:
   using PixelTraits = BGRAPixelTraits;
@@ -155,6 +157,8 @@ public:
   }
 };
 
+#endif /* !GREYSCALE */
+
 #if CLANG_OR_GCC_VERSION(4,8)
 #pragma GCC diagnostic pop
 #endif
