@@ -33,7 +33,7 @@ LargeTextWindow::Create(ContainerWindow &parent, PixelRect rc,
 {
   origin = 0;
 
-  Window::Create(&parent, rc, style);
+  NativeWindow::Create(&parent, rc, style);
 }
 
 unsigned
@@ -80,7 +80,7 @@ LargeTextWindow::ScrollVertically(int delta_lines)
 void
 LargeTextWindow::OnResize(PixelSize new_size)
 {
-  Window::OnResize(new_size);
+  NativeWindow::OnResize(new_size);
 
   if (!value.empty()) {
     /* revalidate the scroll position */
@@ -94,14 +94,31 @@ LargeTextWindow::OnResize(PixelSize new_size)
   }
 }
 
+void
+LargeTextWindow::OnSetFocus()
+{
+  NativeWindow::OnSetFocus();
+  Invalidate();
+}
+
+void
+LargeTextWindow::OnKillFocus()
+{
+  NativeWindow::OnKillFocus();
+  Invalidate();
+}
+
 void
 LargeTextWindow::OnPaint(Canvas &canvas)
 {
   canvas.ClearWhite();
 
-  PixelRect rc(0, 0, canvas.GetWidth() - 1, canvas.GetHeight() - 1);
+  auto rc = canvas.GetRect();
   canvas.DrawOutlineRectangle(rc, COLOR_BLACK);
 
+  if (HasFocus())
+    canvas.DrawFocusRectangle(rc.WithPadding(1));
+
   if (value.empty())
     return;
 
@@ -145,7 +162,16 @@ LargeTextWindow::OnKeyDown(unsigned key_code)
     return true;
   }
 
-  return Window::OnKeyDown(key_code);
+  return NativeWindow::OnKeyDown(key_code);
+}
+
+bool
+LargeTextWindow::OnMouseDown(PixelPoint p)
+{
+  if (IsTabStop())
+    SetFocus();
+
+  return true;
 }
 
 void
