@@ -353,7 +353,7 @@ TestBorgeltB50()
   ok1(equals(nmea_info.settings.bugs, 0.9));
   ok1(nmea_info.settings.ballast_overload_available);
   ok1(equals(nmea_info.settings.ballast_overload, 1.3));
-  ok1(nmea_info.switch_state.flight_mode == SwitchState::FlightMode::CIRCLING);
+  ok1(nmea_info.switch_state.flight_mode == SwitchState::FlightMode::CRUISE);
   ok1(nmea_info.temperature_available);
   ok1(equals(nmea_info.temperature.ToKelvin(), 245.15));
 
@@ -1585,7 +1585,10 @@ TestDeclare(const struct DeviceRegister &driver)
       break;
   }
 
-  device->EnableNMEA(env);
+  try {
+    device->EnableNMEA(env);
+  } catch (...) {
+  }
 
   ok1(port.baud_rate == FaultInjectionPort::DEFAULT_BAUD_RATE);
 
@@ -1616,7 +1619,10 @@ TestFlightList(const struct DeviceRegister &driver)
       break;
   }
 
-  device->EnableNMEA(env);
+  try {
+    device->EnableNMEA(env);
+  } catch (...) {
+  }
 
   ok1(port.baud_rate == FaultInjectionPort::DEFAULT_BAUD_RATE);
 
